@@ -156,7 +156,7 @@ class Database:
                     err_msg += error + ','
             print(err_msg)
 
-    def get_hk_fut_ohlc(self, index, freq, start_date, end_date, rolling_day, rolling_time):
+    def get_hk_fut_ohlc(self, index, start_date, end_date, freq, rolling_day, rolling_time):
         
         check_bool_dict = self.check_hk_fut_ohlc_args(index, freq, start_date, end_date, rolling_day, rolling_time)
 
@@ -166,7 +166,7 @@ class Database:
             end_date_dt = datetime.datetime.strptime(str(end_date), '%Y%m%d').date()
 
             start_date_year = start_date_dt.year if start_date_dt.month > 1 else start_date_dt.year - 1
-            end_date_year = end_date_dt.year if end_date_dt.month < 12 else end_date_dt.year + 1
+            end_date_year = end_date_dt.year if end_date_dt.month < 11 else end_date_dt.year + 1
             
             holiday_dict = get_hk_holiday_and_expiry_date(start_date_year, end_date_year, 'datetime')
             expiry_date_list = holiday_dict['expiry_date']
@@ -227,18 +227,18 @@ class Database:
                 if len(sub_df_list) > 0:
                     df = pd.concat(sub_df_list)
                     df = df.reset_index(drop=True)
-                    date_list = list(df['date'].unique())
-                    date_list.sort()
+                    temp_date_list = list(df['date'].unique())
+                    temp_date_list.sort()
+                    
+                    date_list = []
+                    for temp_date in temp_date_list:
+                        if datetime.datetime.strptime(str(temp_date),'%Y%m%d').weekday() < 5:
+                            date_list.append(temp_date)
+
                     front_year_month = str(date_list[0])[2:6]
                     back_year_month = str(date_list[-1])[2:6]
                     front_expiry_date = int(expiry_date_dict[front_year_month].strftime('%Y%m%d'))
-                    try:
-                        back_expiry_date = int(expiry_date_dict[back_year_month].strftime('%Y%m%d'))
-                    except:
-                        print(back_year_month)
-                        print(date_list)
-                        print(expiry_date_dict)
-                        time.sleep(123456)
+                    back_expiry_date = int(expiry_date_dict[back_year_month].strftime('%Y%m%d'))
 
                     for i in range(len(date_list)):
                         date_item = date_list[i]
@@ -444,12 +444,14 @@ class Database:
         database_str = 'database=' + 'us_earning_calendar_by_code'
         code_str = 'code=' + code
         link_str = link_url + code_str + '&' + token_str + '&' + database_str
-
         
         response = requests.get(link_str)
         result = ast.literal_eval(json.loads(response.content))
 
-        date_list = list(result)
+        temp_list = list(result)
+        date_list = []
+        for date in temp_list:
+            date_list.append(datetime.datetime.strptime(date,'%Y-%m-%d').date())
 
         return date_list
     def get_us_earning_calendar_by_date(self, start_date, end_date):
@@ -517,8 +519,12 @@ class Database:
             df['date'] = pd.to_datetime(df['date'], format='%Y%m%d')
             df = df.set_index('date')
             df = df.sort_index()
-            df = df.reset_index(drop=False)
-
+            #df = df.reset_index(drop=False)
+            
+            for col in df.columns:
+                if 'participants_participant_' in col:
+                    df = df.rename(columns={col:col.replace('participants_participant_','participants_')})
+            
             return df
 
         else:
@@ -556,7 +562,9 @@ class Database:
 
             df = df.sort_values(['date', 'share'], ascending=False)
             df = df[['date', 'ccass_id', 'name', 'share', 'percent']]
-
+            df = df.reset_index(drop=True)
+            df['date'] = pd.to_datetime(df['date'],format ='%Y%m%d')
+            
             return df
 
         else:
@@ -575,9 +583,10 @@ class Database:
         response = requests.get(link_str)
         result = ast.literal_eval(json.loads(response.content))
 
-        name_list = list(result)
+        df = pd.DataFrame(result)
 
-        return name_list
+        return df
+    
     def get_ccass_by_id(self, ccass_id, start_date, end_date):
 
         check_bool_dict = self.check_ccass_by_id_args(ccass_id, start_date, end_date)
@@ -691,6 +700,9 @@ class Database:
             df['date_diff'] = df['date_last'] - df['date_first']
             df = df.dropna()
 
+            for col in df.columns:
+                if 'share' in col:
+                    df[col] = df[col].astype(int)
             return df
 
         else:
@@ -712,9 +724,14 @@ class Database:
 
         df = pd.DataFrame(result)
         df['is_active'] = df['is_active'].astype(bool) 
-        df['is_delisted'] = df['is_delisted'].astype(bool) 
+        df['is_delisted'] = df['is_delisted'].astype(bool)
+
+        for col in df.columns:
+            if col == 'start_date' or col == 'end_date':
+                df[col] = pd.to_datetime(df[col], format='%Y-%m-%d')
 
         return df
+    
     def get_hk_index_const(self, index_name):
         
         if len(index_name) > 0:
@@ -730,12 +747,28 @@ class Database:
 
             df = pd.DataFrame(result)
             df['code'] = df['code'].str.zfill(5)
-        
+            
+            for col in df.columns:
+                if col == 'start_date' or col == 'end_date':
+                    df[col] = pd.to_datetime(df[col], format='%Y-%m-%d')
+            
+            if index_name == 'hsi_const_hist':
+                end_date_list = df['end_date'].to_list()
+                latest_date = max(set(end_date_list), key=end_date_list.count)
+                for i in range(len(df)):
+                    end_date = df.loc[i,'end_date']
+                    if end_date == latest_date:
+                        last_sunday = datetime.datetime.now() - datetime.timedelta(days=((datetime.datetime.now().isoweekday()) % 7))
+                        df.at[i, 'end_date'] = last_sunday.date()
+                    else:
+                        df.at[i, 'end_date'] = end_date.date()
+
             return df
 
         else:
             err_msg =  'index_name missing'
             print(err_msg)
+            
     def get_hk_stock_plate_const(self, plate_name):
         
         if len(plate_name) > 0:
@@ -770,6 +803,8 @@ class Database:
         result = ast.literal_eval(json.loads(response.content))
 
         name_list = list(result)
+        if 'hk_full_market' in name_list:
+            name_list.remove('hk_full_market')
 
         return name_list
     def get_all_hk_stock_plate_name(self):
@@ -957,11 +992,20 @@ class Database:
                     cols = list(df.columns)
                     cols = [cols[-1]] + cols[:-1]
                     df = df[cols]
+                df = df.reset_index(drop=True)
 
             elif deri == 'fut':
                 df = df.sort_values(by='date')
+                df = df.set_index('date')
+                #df = df.reset_index(drop=True)
+
+            if 'strike_price' in df.columns:
+                df = df.rename(columns={'strike_price': 'strike'})
+            if 'change_in_settlement' in df.columns:
+                df = df.rename(columns={'change_in_settlement': 'close_change'})
+            if 'year_month' in df.columns:
+                df = df.rename(columns={'year_month': 'contract_month'})
 
-            df = df.reset_index(drop=True)
             
             return df
 
